# cathalla

The Valhalla of Python

Warning: This is a joke... or not.

## Documentation

See https://impalah.github.io/cathalla/

## Installation

Installing from PyPI:

```bash
pip install cathalla
```

Or from the awesome source code:
```bash
git clone git@github.com:impalah/cathalla.git
```

## Usage

From the Python shell::

```bash
import cathalla
```

Enjoy the wisdom!

## Contributing

Clearly, the code that generates `CATHALLA` is too straightforward.

If you can make it better, then do so.

